import * as react_jsx_runtime from 'react/jsx-runtime';
import { SpacingTypes } from '@versini/ui-spacing-types';

declare const TOGGLE_CLASSNAME = "av-toggle";

type ToggleProps = {
	/**
	 * The label to use for the component.
	 */
	label: string;
	/**
	 * The name to use for the component.
	 */
	name: string;
	/**
	 * Callback fired when the component is activated.
	 * @param checked whether or not the component is checked
	 */
	onChange: (checked: boolean) => void;
	/**
	 * Whether or not the component is checked.
	 * @default false
	 */
	checked?: boolean;
	/**
	 * The type of focus for the Button. This will change the color
	 * of the focus ring around the Button.
	 */
	focusMode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * Whether or not to render the label.
	 * @default false
	 */
	labelHidden?: boolean;
	/**
	 * The type of Toggle. This will change the color of the Toggle.
	 */
	mode?: "dark" | "light" | "system" | "alt-system";
	/**
	 * Whether or not to render the Toggle with a border.
	 * @default false
	 */
	noBorder?: boolean;
} & SpacingTypes.Props;

declare const Toggle: ({ checked, onChange, label, labelHidden, name, mode, focusMode, spacing, noBorder, }: ToggleProps) => react_jsx_runtime.JSX.Element;

export { TOGGLE_CLASSNAME, Toggle };
